==> huaweicloudsdkworkspaceapp-3.1.125-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/update_policy_template_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdatePolicyTemplateRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'policy_template_id': 'str',
        'body': 'UpdatePolicyTemplateReq'
    }

    attribute_map = {
        'policy_template_id': 'policy_template_id',
        'body': 'body'
    }

    def __init__(self, policy_template_id=None, body=None):
        """UpdatePolicyTemplateRequest

        The model defined in huaweicloud sdk

        :param policy_template_id: 策略模板id。
        :type policy_template_id: str
        :param body: Body of the UpdatePolicyTemplateRequest
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        
        

        self._policy_template_id = None
        self._body = None
        self.discriminator = None

        self.policy_template_id = policy_template_id
        if body is not None:
            self.body = body

    @property
    def policy_template_id(self):
        """Gets the policy_template_id of this UpdatePolicyTemplateRequest.

        策略模板id。

        :return: The policy_template_id of this UpdatePolicyTemplateRequest.
        :rtype: str
        """
        return self._policy_template_id

    @policy_template_id.setter
    def policy_template_id(self, policy_template_id):
        """Sets the policy_template_id of this UpdatePolicyTemplateRequest.

        策略模板id。

        :param policy_template_id: The policy_template_id of this UpdatePolicyTemplateRequest.
        :type policy_template_id: str
        """
        self._policy_template_id = policy_template_id

    @property
    def body(self):
        """Gets the body of this UpdatePolicyTemplateRequest.

        :return: The body of this UpdatePolicyTemplateRequest.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdatePolicyTemplateRequest.

        :param body: The body of this UpdatePolicyTemplateRequest.
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePolicyTemplateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.145-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/update_policy_template_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdatePolicyTemplateRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'policy_template_id': 'str',
        'body': 'UpdatePolicyTemplateReq'
    }

    attribute_map = {
        'policy_template_id': 'policy_template_id',
        'body': 'body'
    }

    def __init__(self, policy_template_id=None, body=None):
        r"""UpdatePolicyTemplateRequest

        The model defined in huaweicloud sdk

        :param policy_template_id: 策略模板id。
        :type policy_template_id: str
        :param body: Body of the UpdatePolicyTemplateRequest
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        
        

        self._policy_template_id = None
        self._body = None
        self.discriminator = None

        self.policy_template_id = policy_template_id
        if body is not None:
            self.body = body

    @property
    def policy_template_id(self):
        r"""Gets the policy_template_id of this UpdatePolicyTemplateRequest.

        策略模板id。

        :return: The policy_template_id of this UpdatePolicyTemplateRequest.
        :rtype: str
        """
        return self._policy_template_id

    @policy_template_id.setter
    def policy_template_id(self, policy_template_id):
        r"""Sets the policy_template_id of this UpdatePolicyTemplateRequest.

        策略模板id。

        :param policy_template_id: The policy_template_id of this UpdatePolicyTemplateRequest.
        :type policy_template_id: str
        """
        self._policy_template_id = policy_template_id

    @property
    def body(self):
        r"""Gets the body of this UpdatePolicyTemplateRequest.

        :return: The body of this UpdatePolicyTemplateRequest.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdatePolicyTemplateRequest.

        :param body: The body of this UpdatePolicyTemplateRequest.
        :type body: :class:`huaweicloudsdkworkspaceapp.v1.UpdatePolicyTemplateReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePolicyTemplateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
